==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/assist/help/help_movephones.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html>
<title>Help - Move Phones</title>
<head>
<script type="text/javascript">
	var state = {};
	var title = 'Help';
	var url   = '/manager/assist/help';
	history.pushState(state, title, url);
</script>
<link href="/manager/assist/css/Styles.css" rel="stylesheet" type="text/css">
<script src="/manager/assist/js/wiz/jquery-1.8.0.js" type="text/javascript"></script>
<script type="text/javascript">
$(function() {
	$(window).scroll(function() {
		if($(this).scrollTop() != 0) {
			$('#toTop').fadeIn();
		} else {
			$('#toTop').fadeOut();
		}
	});

	$('#toTop').click(function() {
		$('body,html').animate({scrollTop:0},800);
	});
});
</script>
</head>
<body>
<div id="toTop">^ Back to Top</div>
<div id="contain">
<h2><img src='/manager/assist/images/help.png' style="vertical-align:middle;">&nbsp;Help - Move Phones</h2>
<b>Move Phones/PCS - Between Modules. Fix POTS</b><br/>
<p>This page is primarily for moving users between different modules, perhaps because a 4315 is being replaced by a 5330<br/><br/>
When users are moved from one module to another the users initial phone is changed to the module they have been moved to. If the module they are being moved from matches their Current Home this will also be changed to be the module they have been moved to.<br/><br/>
When Pots ports are moved onto a "Member" of the system the destination always starts with port01.<br/><br/>
To use this feature select the tick box in the 'From' column which applies to the module you wish to move users from, then select the tick box in the 'To' column next to the module you wish to move users to.<br/>
Once you have selected the from and to options a box appears inviting you to 'move phones' - <b>DOUBLE CHECK YOUR SELECTIONS before clicking this box</b>.<br/><br/>
Clicking Move Phones will move the users from your choosen Module to the New Module.<br/><br/>
<b>Temporary Modules</b><br/>
Temporary modules can be used to move users to whilst a physical module is being updated or replaced. You should ensure all users are moved to actual modules BEFORE removing the temporary module.<br/><br/>
<b>Add Temp Module</b><br/>
Clicking Add Temp Modules adds 3 new modules to the system. A new CallSever 5100, 5315 and 5330 Phone Module are added. Each Module is called 'zczc temp' followed by the module number.<br/><br/>
<b>Delete Temp Module</b><br/>
Clicking Delete Temp Modules removes the 3 new 5 series temporary modules that were added.<br/><br/>
<b>Fix POTS Ports</b><br/>
Fix POTS Ports can be used to ensure the correct number of POTS users are allocated to a module.<br/><br/>
<b>Create System Backup</b><br/>
Clicking Create System Backup will cause a database backup to be created. During the process an animated progress bar is shown. Once the backup has been created the script will show 'Backup Created'.<br/><br/>


</div>
</body>
</html>

==> SV1000-Linux.SV1.3.117.tar.gz: SpliceCom/WebManager/assist/help/help_movephones.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html>
<title>Help - Move Phones</title>
<head>
<script type="text/javascript">
	var state = {};
	var title = 'Help';
	var url   = '/manager/assist/help';
	history.pushState(state, title, url);
</script>
<link href="/manager/assist/css/Styles.css" rel="stylesheet" type="text/css">
<script src="/manager/assist/js/wiz/jquery-1.8.0.js" type="text/javascript"></script>
<script type="text/javascript">
$(function() {
	$(window).scroll(function() {
		if($(this).scrollTop() != 0) {
			$('#toTop').fadeIn();
		} else {
			$('#toTop').fadeOut();
		}
	});

	$('#toTop').click(function() {
		$('body,html').animate({scrollTop:0},800);
	});
});
</script>
</head>
<body>
<div id="toTop">^ Back to Top</div>
<div id="contain">
<h2><img src='/manager/assist/images/help.png' style="vertical-align:middle;">&nbsp;Help - Move Phones</h2>
<b>Move Phones/PCS - Between Modules. Fix POTS</b><br/>
<p>This page is primarily for moving users between different modules, perhaps because a 4315 is being replaced by a 5330<br/><br/>
When users are moved from one module to another the users initial phone is changed to the module they have been moved to. If the module they are being moved from matches their Current Home this will also be changed to be the module they have been moved to.<br/><br/>
When Pots ports are moved onto a "Member" of the system the destination always starts with port01.<br/><br/>
To use this feature select the tick box in the 'From' column which applies to the module you wish to move users from, then select the tick box in the 'To' column next to the module you wish to move users to.<br/>
Once you have selected the from and to options a box appears inviting you to 'move phones' - <b>DOUBLE CHECK YOUR SELECTIONS before clicking this box</b>.<br/><br/>
Clicking Move Phones will move the users from your choosen Module to the New Module.<br/><br/>
<b>Temporary Modules</b><br/>
Temporary modules can be used to move users to whilst a physical module is being updated or replaced. You should ensure all users are moved to actual modules BEFORE removing the temporary module.<br/><br/>
<b>Add Temp Module</b><br/>
Clicking 'Add Temp Modules' adds 2 new modules to the system. A new 5330 and P308 Phone Module are added. Each Module is called 'zczc temp' followed by the module number.<br/><br/>
<b>Delete Temp Module</b><br/>
Clicking 'Delete Temp Modules' removes the 2 new temporary modules that were added.<br/><br/>
<b>Fix POTS Ports</b><br/>
Fix POTS Ports can be used to ensure the correct number of POTS users are allocated to a module.<br/><br/>
<b>Create System Backup</b><br/>
Clicking Create System Backup will cause a database backup to be created. During the process an animated progress bar is shown. Once the backup has been created the script will show 'Backup Created'.<br/><br/>


</div>
</body>
</html>
